# Explanation

Understand how and why Jnkn works.

## Architecture

- [Overview](architecture/overview.md) — High-level system design
- [Parsing Pipeline](architecture/parsing-pipeline.md) — How code becomes a graph
- [Stitching Engine](architecture/stitching-engine.md) — How cross-domain links are made
- [Confidence Model](architecture/confidence-model.md) — How match quality is scored

## Concepts

- [Dependency Graph](concepts/dependency-graph.md) — The core data structure
- [Blast Radius](concepts/blast-radius.md) — Understanding impact analysis
- [Cross-Domain Dependencies](concepts/cross-domain-deps.md) — The problem Jnkn solves

## Design Decisions

- [Why Tree-Sitter](design-decisions/why-tree-sitter.md) — Parser technology choice
- [Why Token Matching](design-decisions/why-token-matching.md) — Matching strategy rationale

## Security

- [Threat Model](security/threat-model.md) — Security considerations
